@@ -1,3 +1,4 @@
+/* vim:set ft=c ts=2 sw=2 sts=2 et cindent: */
 /*
  * ***** BEGIN LICENSE BLOCK *****
  * Version: MIT
@@ -45,11 +46,18 @@
 #include <string.h>
 #include <sys/types.h>
 
-char const *amqp_version(void) { return AMQP_VERSION_STRING; }
+char const *amqp_version(void)
+{
+  return AMQP_VERSION_STRING;
+}
 
-uint32_t amqp_version_number(void) { return AMQP_VERSION; }
+uint32_t amqp_version_number(void)
+{
+  return AMQP_VERSION;
+}
 
-void init_amqp_pool(amqp_pool_t *pool, size_t pagesize) {
+void init_amqp_pool(amqp_pool_t *pool, size_t pagesize)
+{
   pool->pagesize = pagesize ? pagesize : 4096;
 
   pool->pages.num_blocks = 0;
@@ -63,33 +71,37 @@ void init_amqp_pool(amqp_pool_t *pool, size_t pagesize) {
   pool->alloc_used = 0;
 }
 
-static void empty_blocklist(amqp_pool_blocklist_t *x) {
+static void empty_blocklist(amqp_pool_blocklist_t *x)
+{
   int i;
 
+  for (i = 0; i < x->num_blocks; i++) {
+    free(x->blocklist[i]);
+  }
   if (x->blocklist != NULL) {
-    for (i = 0; i < x->num_blocks; i++) {
-      free(x->blocklist[i]);
-    }
     free(x->blocklist);
   }
   x->num_blocks = 0;
   x->blocklist = NULL;
 }
 
-void recycle_amqp_pool(amqp_pool_t *pool) {
+void recycle_amqp_pool(amqp_pool_t *pool)
+{
   empty_blocklist(&pool->large_blocks);
   pool->next_page = 0;
   pool->alloc_block = NULL;
   pool->alloc_used = 0;
 }
 
-void empty_amqp_pool(amqp_pool_t *pool) {
+void empty_amqp_pool(amqp_pool_t *pool)
+{
   recycle_amqp_pool(pool);
   empty_blocklist(&pool->pages);
 }
 
 /* Returns 1 on success, 0 on failure */
-static int record_pool_block(amqp_pool_blocklist_t *x, void *block) {
+static int record_pool_block(amqp_pool_blocklist_t *x, void *block)
+{
   size_t blocklistlength = sizeof(void *) * (x->num_blocks + 1);
 
   if (x->blocklist == NULL) {
@@ -110,7 +122,8 @@ static int record_pool_block(amqp_pool_blocklist_t *x, void *block) {
   return 1;
 }
 
-void *amqp_pool_alloc(amqp_pool_t *pool, size_t amount) {
+void *amqp_pool_alloc(amqp_pool_t *pool, size_t amount)
+{
   if (amount == 0) {
     return NULL;
   }
@@ -123,7 +136,6 @@ void *amqp_pool_alloc(amqp_pool_t *pool, size_t amount) {
       return NULL;
     }
     if (!record_pool_block(&pool->large_blocks, result)) {
-      free(result);
       return NULL;
     }
     return result;
@@ -158,20 +170,22 @@ void *amqp_pool_alloc(amqp_pool_t *pool, size_t amount) {
   return pool->alloc_block;
 }
 
-void amqp_pool_alloc_bytes(amqp_pool_t *pool, size_t amount,
-                           amqp_bytes_t *output) {
+void amqp_pool_alloc_bytes(amqp_pool_t *pool, size_t amount, amqp_bytes_t *output)
+{
   output->len = amount;
   output->bytes = amqp_pool_alloc(pool, amount);
 }
 
-amqp_bytes_t amqp_cstring_bytes(char const *cstr) {
+amqp_bytes_t amqp_cstring_bytes(char const *cstr)
+{
   amqp_bytes_t result;
   result.len = strlen(cstr);
-  result.bytes = (void *)cstr;
+  result.bytes = (void *) cstr;
   return result;
 }
 
-amqp_bytes_t amqp_bytes_malloc_dup(amqp_bytes_t src) {
+amqp_bytes_t amqp_bytes_malloc_dup(amqp_bytes_t src)
+{
   amqp_bytes_t result;
   result.len = src.len;
   result.bytes = malloc(src.len);
@@ -181,23 +195,27 @@ amqp_bytes_t amqp_bytes_malloc_dup(amqp_bytes_t src) {
   return result;
 }
 
-amqp_bytes_t amqp_bytes_malloc(size_t amount) {
+amqp_bytes_t amqp_bytes_malloc(size_t amount)
+{
   amqp_bytes_t result;
   result.len = amount;
   result.bytes = malloc(amount); /* will return NULL if it fails */
   return result;
 }
 
-void amqp_bytes_free(amqp_bytes_t bytes) { free(bytes.bytes); }
+void amqp_bytes_free(amqp_bytes_t bytes)
+{
+  free(bytes.bytes);
+}
 
-amqp_pool_t *amqp_get_or_create_channel_pool(amqp_connection_state_t state,
-                                             amqp_channel_t channel) {
+amqp_pool_t *amqp_get_or_create_channel_pool(amqp_connection_state_t state, amqp_channel_t channel)
+{
   amqp_pool_table_entry_t *entry;
   size_t index = channel % POOL_TABLE_SIZE;
 
   entry = state->pool_table[index];
 
-  for (; NULL != entry; entry = entry->next) {
+  for ( ; NULL != entry; entry = entry->next) {
     if (channel == entry->channel) {
       return &entry->pool;
     }
@@ -217,14 +235,14 @@ amqp_pool_t *amqp_get_or_create_channel_pool(amqp_connection_state_t state,
   return &entry->pool;
 }
 
-amqp_pool_t *amqp_get_channel_pool(amqp_connection_state_t state,
-                                   amqp_channel_t channel) {
+amqp_pool_t *amqp_get_channel_pool(amqp_connection_state_t state, amqp_channel_t channel)
+{
   amqp_pool_table_entry_t *entry;
   size_t index = channel % POOL_TABLE_SIZE;
 
   entry = state->pool_table[index];
 
-  for (; NULL != entry; entry = entry->next) {
+  for ( ; NULL != entry; entry = entry->next) {
     if (channel == entry->channel) {
       return &entry->pool;
     }
