@@ -1,22 +1,55 @@
-// Copyright 2007 - 2021, Alan Antonuk and the rabbitmq-c contributors.
-// SPDX-License-Identifier: mit
+/* vim:set ft=c ts=2 sw=2 sts=2 et cindent: */
+/*
+ * ***** BEGIN LICENSE BLOCK *****
+ * Version: MIT
+ *
+ * Portions created by Alan Antonuk are Copyright (c) 2012-2013
+ * Alan Antonuk. All Rights Reserved.
+ *
+ * Portions created by VMware are Copyright (c) 2007-2012 VMware, Inc.
+ * All Rights Reserved.
+ *
+ * Portions created by Tony Garnock-Jones are Copyright (c) 2009-2010
+ * VMware, Inc. and Tony Garnock-Jones. All Rights Reserved.
+ *
+ * Permission is hereby granted, free of charge, to any person
+ * obtaining a copy of this software and associated documentation
+ * files (the "Software"), to deal in the Software without
+ * restriction, including without limitation the rights to use, copy,
+ * modify, merge, publish, distribute, sublicense, and/or sell copies
+ * of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be
+ * included in all copies or substantial portions of the Software.
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+ * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
+ * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
+ * BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
+ * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
+ * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+ * SOFTWARE.
+ * ***** END LICENSE BLOCK *****
+ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
 #ifdef _MSC_VER
-#define _CRT_SECURE_NO_WARNINGS
+# define _CRT_SECURE_NO_WARNINGS
 #endif
 
 #include "amqp_private.h"
-#include <limits.h>
 #include <stdint.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 
-void amqp_default_connection_info(struct amqp_connection_info *ci) {
+void amqp_default_connection_info(struct amqp_connection_info *ci)
+{
   /* Apply defaults */
   ci->user = "guest";
   ci->password = "guest";
@@ -27,7 +60,8 @@ void amqp_default_connection_info(struct amqp_connection_info *ci) {
 }
 
 /* Scan for the next delimiter, handling percent-encodings on the way. */
-static char find_delim(char **pp, int colon_and_at_sign_are_delims) {
+static char find_delim(char **pp, int colon_and_at_sign_are_delims)
+{
   char *from = *pp;
   char *to = from;
 
@@ -35,58 +69,57 @@ static char find_delim(char **pp, int colon_and_at_sign_are_delims) {
     char ch = *from++;
 
     switch (ch) {
-      case ':':
-      case '@':
-        if (!colon_and_at_sign_are_delims) {
-          *to++ = ch;
-          break;
-        }
-
-      /* fall through */
-      case 0:
-      case '/':
-      case '?':
-      case '#':
-      case '[':
-      case ']':
-        *to = 0;
-        *pp = from;
-        return ch;
-
-      case '%': {
-        unsigned int val;
-        int chars;
-        int res = sscanf(from, "%2x%n", &val, &chars);
-
-        if (res == EOF || res < 1 || chars != 2 || val > CHAR_MAX)
-        /* Return a surprising delimiter to
-           force an error. */
-        {
-          return '%';
-        }
-
-        *to++ = (char)val;
-        from += 2;
+    case ':':
+    case '@':
+      if (!colon_and_at_sign_are_delims) {
+        *to++ = ch;
         break;
       }
 
-      default:
-        *to++ = ch;
-        break;
+      /* fall through */
+    case 0:
+    case '/':
+    case '?':
+    case '#':
+    case '[':
+    case ']':
+      *to = 0;
+      *pp = from;
+      return ch;
+
+    case '%': {
+      unsigned int val;
+      int chars;
+      int res = sscanf(from, "%2x%n", &val, &chars);
+
+      if (res == EOF || res < 1 || chars != 2)
+        /* Return a surprising delimiter to
+           force an error. */
+      {
+        return '%';
+      }
+
+      *to++ = val;
+      from += 2;
+      break;
+    }
+
+    default:
+      *to++ = ch;
+      break;
     }
   }
 }
 
 /* Parse an AMQP URL into its component parts. */
-int amqp_parse_url(char *url, struct amqp_connection_info *parsed) {
+int amqp_parse_url(char *url, struct amqp_connection_info *parsed)
+{
   int res = AMQP_STATUS_BAD_URL;
   char delim;
   char *start;
   char *host;
   char *port = NULL;
 
-  amqp_default_connection_info(parsed);
-
   /* check the prefix */
   if (!strncmp(url, "amqp://", 7)) {
     /* do nothing */
@@ -152,7 +185,7 @@ int amqp_parse_url(char *url, struct amqp_connection_info *parsed) {
   }
 
   if (delim == ':') {
-    port = url;
+    port = start = url;
     delim = find_delim(&url, 1);
   }
 
@@ -181,7 +214,8 @@ int amqp_parse_url(char *url, struct amqp_connection_info *parsed) {
     res = AMQP_STATUS_OK;
   }
 
-  /* Any other delimiter is bad, and we will return AMQP_STATUS_BAD_AMQP_URL. */
+  /* Any other delimiter is bad, and we will return
+     AMQP_STATUS_BAD_AMQP_URL. */
 
 out:
   return res;
